Task: ConvAI2
==============
Description: A chit-chat dataset based on PersonaChat (https://arxiv.org/abs/1801.07243) for a NIPS 2018 competition. 

Link: http://convai.io/.

Tags: #ConvAI2, #All, #ChitChat


License: CC 4.0 BY
